=========
Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog <https://keepachangelog.com/en/1.0.0/>`_,
and this project adheres to `Semantic Versioning <https://semver.org/spec/v2.0.0.html>`_.

[Unreleased]
============

Changed
-------

1.0.0 (2019-05-24)
==================

Added
-----
* Remove unwanted Cookiecutter output
* Implement script to create String SSM Parameters from a simple config file stored in YAML

0.1.0 (2019-05-14)
==================

Added
-----

* First release on PyPI.
* Cookiecutter skeleton only, no functionality
